/*
 * Copyright (C) 2019 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once

#include <gmock/gmock.h>

#include <ui/Gralloc.h>

namespace android {

class GraphicBuffer;

namespace mock {

class MockGrallocAllocator : public GrallocAllocator {
public:
    MockGrallocAllocator();
    ~MockGrallocAllocator() override;

    MOCK_METHOD(bool, isLoaded, (), (const, override));
    MOCK_METHOD(std::string, dumpDebugInfo, (bool less), (const, override));
    MOCK_METHOD(status_t, allocate,
                (std::string requestorName, uint32_t width, uint32_t height, PixelFormat format,
                 uint32_t layerCount, uint64_t usage, uint32_t* outStride,
                 buffer_handle_t* outBufferHandles, bool less),
                (const, override));
};

} // namespace mock
} // namespace android
